# Command Line Interface for Lucidtech AI Services

## Installation

```bash
$ pip install lucidtech-las-cli
```

## Usage

Configure program

```bash
las configure
```

Scan Receipt

```bash
las scan receipt --filename img.jpeg
las scan receipt --url https://example.com/img.jpeg
```

Scan Invoice

```bash
las scan invoice --filename img.jpeg
las scan invoice --url https://example.com/img.jpeg
```
